@@ -41,11 +41,19 @@ open EConstr
 let is_global = isRefX
 #endif
 
+#if COQVERSION >= 81800
+let is_global t1 t2 = is_global !global_env t1 t2
+#else
 let is_global t1 t2 = is_global !global_evd t1 t2
+#endif
 
 let kind_of_term t = kind !global_evd t
 
+#if COQVERSION >= 81800
+let decompose_app t = decompose_app_list !global_evd t
+#else
 let decompose_app t = decompose_app !global_evd t
+#endif
 
 let closed0 t = Vars.closed0 !global_evd t
 
@@ -70,7 +78,9 @@ let binder_name = Context.binder_name
 let binder_name x = x
 #endif
 
-#if COQVERSION >= 81300
+#if COQVERSION >= 81700
+let refine_no_check = Tactics.exact_no_check
+#elif COQVERSION >= 81300
 let refine_no_check t =
   Logic.refiner ~check:false (EConstr.Unsafe.to_constr t)
 #elif COQVERSION >= 81200
